@@ -259,6 +259,12 @@ public:
     template<class CT = FileInfo>
     static bool regClass(const QString &scheme, RegOpts opts = RegOpts::kNoOpt, QString *errorString = nullptr)
     {
+        assert(qApp->thread() == QThread::currentThread());
+        static std::once_flag createFlag;
+        // main thread create InfoCacheController
+        std::call_once(createFlag, [] {
+            InfoCacheController::instance();
+        });
         if (opts & RegOpts::kNoCache)
             InfoCacheController::instance().setCacheDisbale(scheme);
         return instance().SchemeFactory<FileInfo>::regClass<CT>(scheme, errorString);
@@ -332,6 +338,13 @@ public:
         return qSharedPointerDynamicCast<T>(info);
     }
 
+    static void cacheFileInfo(const QSharedPointer<FileInfo> &info) {
+        if (InfoCacheController::instance().cacheDisable(info->fileUrl().scheme()))
+            return;
+        emit InfoCacheController::instance().removeCacheFileInfo({info->fileUrl()});
+        emit InfoCacheController::instance().cacheFileInfo(info->fileUrl(), info);
+    }
+
 private:
     static InfoFactory &instance();   // 获取全局实例
     explicit InfoFactory() {}
